@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Scheduler.pm - The otrs Scheduler Daemon
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: Scheduler.pm,v 1.19 2011/07/18 19:45:24 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +17,11 @@ use warnings;
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsStringWithData);
 use Kernel::System::Scheduler::TaskManager;
 use Kernel::Scheduler::TaskHandler;
-use Kernel::System::Registration;
 use Kernel::System::PID;
 
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.19 $) [1];
+
 =head1 NAME
 
 Kernel::Scheduler - Scheduler lib
@@ -49,7 +54,6 @@ create an object.
     use Kernel::Config;
     use Kernel::System::Encode;
     use Kernel::System::Log;
-    use Kernel::System::Time;
     use Kernel::System::Main;
     use Kernel::System::DB;
     use Kernel::Scheduler;
@@ -62,10 +66,6 @@ create an object.
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
     );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
     my $MainObject = Kernel::System::Main->new(
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
@@ -80,7 +80,6 @@ create an object.
     my $SchedulerObject = Kernel::Scheduler->new(
         ConfigObject => $ConfigObject,
         LogObject    => $LogObject,
-        TimeObject   => $TimeObject,
         DBObject     => $DBObject,
         MainObject   => $MainObject,
         EncodeObject => $EncodeObject,
@@ -100,14 +99,12 @@ sub new {
         $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
     }
 
-    # create additional objects
+    # create aditional objects
     $Self->{TaskManagerObject} = Kernel::System::Scheduler::TaskManager->new( %{$Self} );
 
     $Self->{PIDObject} = Kernel::System::PID->new( %{$Self} );
     $Self->{PIDUpdateTime} = $Self->{ConfigObject}->Get('Scheduler::PIDUpdateTime') || 60;
 
-    $Self->{RegistrationObject} = Kernel::System::Registration->new( %{$Self} );
-
     return $Self;
 }
 
@@ -128,13 +125,10 @@ sub Run {
     # try to update PID changed time
     $Self->_PIDChangedTimeUpdate();
 
-    # Perform sanity checks
-    $Self->_SanityChecks();
-
     # get all tasks
     my @TaskList = $Self->{TaskManagerObject}->TaskList();
 
-    # if there are no task to execute return successfully
+    # if there are no task to execute return succesfull
     return 1 if !@TaskList;
 
     # get the task details
@@ -181,17 +175,6 @@ sub Run {
             next TASKITEM;
         }
 
-        if ( !IsHashRefWithData( $TaskData{Data} ) ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => 'Got invalid data inside task data!',
-            );
-            $Self->{TaskManagerObject}->TaskDelete( ID => $TaskItem->{ID} );
-
-            # skip if can't get task data -> data
-            next TASKITEM;
-        }
-
         # create task handler object
         my $TaskHandlerObject = eval {
             Kernel::Scheduler::TaskHandler->new(
@@ -214,49 +197,40 @@ sub Run {
         }
 
         # call run method on task handler object
-        my $TaskResult = $TaskHandlerObject->Run(
-            TaskID => $TaskItem->{ID},
-            Data   => $TaskData{Data},
-        );
+        my $TaskResult = $TaskHandlerObject->Run( Data => $TaskData{Data} );
 
         # try to update PID changed time
         $Self->_PIDChangedTimeUpdate();
 
-        # check if need to reschedule
+        # skip if can't delete task
+        next TASKITEM if !$Self->{TaskManagerObject}->TaskDelete( ID => $TaskItem->{ID} );
+
+        # check if need to re-schedule
         if ( $TaskResult->{ReSchedule} ) {
 
-            # reschedule: update the current task
-            my $Success = $Self->{TaskManagerObject}->TaskUpdate(
-                ID      => $TaskItem->{ID},
-                DueTime => $TaskResult->{DueTime},
-                Data    => $TaskResult->{Data},
-                Type    => $TaskItem->{Type},
+            # set new due time
+            my %ReScheduleTaskData = (
+                DueTime => scalar $TaskResult->{DueTime},
+                Data    => scalar $TaskResult->{Data},
+                Type    => scalar $TaskItem->{Type},
             );
 
-            # check if task was rescheduled successfully
-            if ( !$Success ) {
+            # re-schedule: create a new task
+            my $TaskID = $Self->TaskRegister(%ReScheduleTaskData);
+
+            # check if task was re scheduled successfuly
+            if ( !$TaskID ) {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
-                    Message  => "Could not reschedule task.",
+                    Message  => "Could not re-schedule task",
                 );
-
-                # delete the task
-                $Self->{TaskManagerObject}->TaskDelete( ID => $TaskItem->{ID} );
-
                 next TASKITEM;
             }
-
             $Self->{LogObject}->Log(
-                Priority => 'info',
-                Message  => "Task is rescheduled (TaskID: $TaskItem->{ID}).",
+                Priority => 'notice',
+                Message  => "Task is re-scheduled.",
             );
         }
-
-        else {
-
-            # delete the task
-            $Self->{TaskManagerObject}->TaskDelete( ID => $TaskItem->{ID} );
-        }
     }
 
     return 1;
@@ -268,7 +242,7 @@ schedules a task for asynchronous execution (either as soon as possible, or with
 specified future execution time). Each task has a task type, and for each task type
 a corresponding task handler backend must be present. The task data that is required
 depends on the task type. Please consult the task handler backend specification to find
-out which data is exactly needed.
+out exactly which data is needed.
 
     my $TaskID = $SchedulerObject->TaskRegister(
         Type     => 'GenericInterface',
@@ -290,7 +264,7 @@ sub TaskRegister {
             Message  => 'Got no Task Type with content!',
         );
 
-        # return failure if no task type is sent
+        # retrun failure if no task type is sent
         return;
     }
 
@@ -301,7 +275,7 @@ sub TaskRegister {
             Message  => 'Got undefined Task data!',
         );
 
-        # return error if task data is undefined
+        # retrun error if task data is undefined
         return;
     }
 
@@ -317,7 +291,7 @@ sub TaskRegister {
             Message  => 'Task could not be registered',
         );
 
-        # return failure if task registration fails
+        # retrun failure if task registration fails
         return;
     }
 
@@ -325,69 +299,6 @@ sub TaskRegister {
     return $TaskID;
 }
 
-=item _SanityChecks()
-
-performs checks for the currently registered tasks.
-
-=cut
-
-sub _SanityChecks {
-    my ( $Self, %Param ) = @_;
-
-    $Self->_SanityCheckSystemRegistration();
-
-    return 1;
-}
-
-sub _SanityCheckSystemRegistration {
-    my ( $Self, %Param ) = @_;
-
-    my %RegistrationData = $Self->{RegistrationObject}->RegistrationDataGet();
-
-    # get all tasks
-    my @TaskList = $Self->{TaskManagerObject}->TaskList();
-    my @RegistrationUpdateTaskList = grep { $_->{Type} eq 'RegistrationUpdate' } @TaskList;
-
-    # Registered system, must have RegistrationUpdate task.
-    if ( $RegistrationData{State} && $RegistrationData{State} eq 'registered' ) {
-
-        # Is there exactly 1 task?
-        if ( scalar @RegistrationUpdateTaskList == 1 ) {
-            return 1;
-        }
-        elsif ( scalar @RegistrationUpdateTaskList == 0 ) {
-
-            # Ok, RegistrationUpdate task is missing. Create it.
-            $Self->{TaskManagerObject}->TaskAdd(
-                Type => 'RegistrationUpdate',
-                Data => {
-                    ReSchedule => 1,
-                },
-            );
-        }
-        else {
-            # Ok, there is more than one task. Remove the others.
-            shift @RegistrationUpdateTaskList;
-            for my $RegistrationUpdateTask (@RegistrationUpdateTaskList) {
-                $Self->{TaskManagerObject}->TaskDelete(
-                    ID => $RegistrationUpdateTask->{ID},
-                );
-            }
-        }
-    }
-
-    # Not registered system, may not have RegistrationUpdate task.
-    else {
-        # Delete any remaining tasks.
-        for my $RegistrationUpdateTask (@RegistrationUpdateTaskList) {
-            $Self->{TaskManagerObject}->TaskDelete(
-                ID => $RegistrationUpdateTask->{ID},
-            );
-        }
-    }
-    return 1;
-}
-
 =item _PIDChangedTimeUpdate()
 
 Check if is the case to update the changed time for the PID,
@@ -409,7 +320,7 @@ sub _PIDChangedTimeUpdate {
     }
 
     # get current system time
-    my $CurrentTime = time();
+    my $CurrentTime = $Self->{TimeObject}->SystemTime();
 
     # check if it's necessary to update change time for pid
     if ( $CurrentTime >= $Self->{PIDTimeToUpdate} ) {
@@ -445,3 +356,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.19 $ $Date: 2011/07/18 19:45:24 $
+
+=cut
